@@ -198,6 +198,7 @@ public class CDFConvert extends JFrame
 /** The command string. */
     String command = "cdfconvert ";
     String commandX;
+    String[] cmds = new String[3];
 
 /** Environment variable for the current directory. */
     String currentdir = System.getProperty("user.dir");
@@ -604,7 +605,7 @@ public class CDFConvert extends JFrame
         makeJButton(panel2n, tpanel2, 3, 1, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, dpc, 0, 2, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, rec, 1, 2, 1, 1, 1.0, 1.0);
-        makeJButton(panel2n, bac, 2, 2, 1, 1, 1.0, 1.0);
+//        makeJButton(panel2n, bac, 2, 2, 1, 1, 1.0, 1.0);
         tpanel4.add(ZMODE,BorderLayout.WEST);
         tpanel4.add(zmodePanel, BorderLayout.CENTER);
         tpanel4.add(Box.createRigidArea(hpad20), BorderLayout.EAST);
@@ -768,9 +769,19 @@ public class CDFConvert extends JFrame
 	} else if (obj == helpb || obj == menuHelpHelp) { // for "Help" 
 		commandX = command + "-java";
 		hlp = 1;
-                // String[] cmds = {"/bin/sh", "-c", commandX};
-                // runit(cmds);
-                runit(commandX);
+		iba = 0;
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+                runit(cmds);
+                // runit(commandX);
 		hlp = 0;
 	} else if (obj == entrb) { // for "Enter" button
                 cdfspec = cdf1.getText();
@@ -778,10 +789,12 @@ public class CDFConvert extends JFrame
                 if ((filespec.equals("") || filespec.trim().equals("")) ||
                     (cdfspec.equals("") || cdfspec.trim().equals(""))) {
                   info.setText("");
-                  info.append("Please enter a source and destination CDF for a batch run..");
+                  info.append("Please enter a source and destination CDF...");
                   Toolkit.getDefaultToolkit().beep();
                   return;
                 }
+                filespec = filespec.trim();
+                cdfspec = cdfspec.trim();
 
 		temp = strri + strrw + strre;
 		if (temp.length() == 0) report = " ";
@@ -844,27 +857,30 @@ public class CDFConvert extends JFrame
 
                 if (cdfspec.startsWith("'")) cdfDelimiter = " ";
                 else if (cdfspec.startsWith("\"")) cdfDelimiter = " ";
-                else cdfDelimiter = "'";
+                else cdfDelimiter = "\"";
 
-		if (filespec.trim().equals("")) fileDelimiter = " ";
-                else if (filespec.startsWith("'")) fileDelimiter = " ";
+                if (filespec.startsWith("'")) fileDelimiter = " ";
                 else if (filespec.startsWith("\"")) fileDelimiter = " ";
-                else fileDelimiter = "'";
+                else fileDelimiter = "\"";
 
-		if (skeletonFile.trim().equals("")) sktDelimiter = " ";
-                else if (skeletonFile.startsWith("'")) sktDelimiter = " ";
-                else if (skeletonFile.startsWith("\"")) sktDelimiter = " ";
-                else sktDelimiter = "'";
+                String yyy;
+                if (skeleton.equals(" "))
+                  yyy = "";
+                else {
+                  if (skeletonFile.startsWith("'")) sktDelimiter = " ";
+                  else if (skeletonFile.startsWith("\"")) sktDelimiter = " ";
+                  else sktDelimiter = "\"";
+                  yyy = sktDelimiter + skeletonFile.trim() + sktDelimiter;
+                }
 
-		/********************************
-                commandX = command + strpo + strds + strlp + skeleton + 
-			   sktDelimiter + skeletonFile + sktDelimiter +
+                commandX = command + strpo + strds + strlp + skeleton + yyy +
+//			   sktDelimiter + skeletonFile + sktDelimiter +
                            Caches + report + cdfDelimiter + cdfspec + 
 			   cdfDelimiter + Zmode + strzz + fileDelimiter +  
 			   filespec + fileDelimiter + " " + Format + 
 			   Majority + Encoding + strde + Compression + 
                            Sparseness + " " + strbw + " " + Checksum;
-                *********************************/
+                /*********************************
 		commandX = command + strpo + strds + strlp + skeleton + 
 			   " " + skeletonFile + " " +
                            Caches + report + " "+ cdfspec + " " + 
@@ -872,10 +888,20 @@ public class CDFConvert extends JFrame
                            " " + Format + 
 			   Majority + Encoding + strde + Compression + 
                            Sparseness + " " + strbw + " " + Checksum;
-
-                // String[] cmds = {"/bin/sh", "-c", commandX};
-                // runit(cmds);
-                runit(commandX);
+		*********************************/
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    commandX = commandX.replace('-', '/');
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+                runit(cmds);
+                // runit(commandX);
 	} else if (obj == cdf1) {
 		cdfspec = cdf1.getText();
 	} else if (obj == cdf2) {
@@ -998,10 +1024,20 @@ public class CDFConvert extends JFrame
         } else if (obj == abc) { // "About" checkbox 
 	   if (abc.isSelected()) {
 		abcX = 1;
+		iba = 0;
 		commandX = command + " -about";
-                // String[] cmds = {"/bin/sh", "-c", commandX};
-                // runit(cmds);
-                runit(commandX);
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+                runit(cmds);
+                // runit(commandX);
 		abc.setSelected(false);
 		abcX = 0;
 	   }
@@ -1140,51 +1176,53 @@ public class CDFConvert extends JFrame
     the results in the text area.
  */
 
-    // private void runit(String[] command) {
-    private void runit(String command) {
+    private void runit(String[] command) {
+    // private void runit(String command) {
 	try {
-           if (System.getProperty("os.name").toLowerCase().indexOf("vms") != -1)
-              command = command.replace('-', '/');
-
-		// if (System.getProperty("os.name").equalsIgnoreCase("VMS"))
-		//   command[2] = command[2].replace('-', '/');
-                process = runtime.exec(command);
+                if (command[1] != null)
+                  process = runtime.exec(command);
+                else
+                  process = runtime.exec(command[0]);
 
 		if (iba == 1 && hlp == 0 && abcX == 0) {
                    info.setText("Program is submitted...\n\n");
-		   info.append("A CDF: " + filespec.trim() + 
+		   info.append("A CDF: " + filespec + 
 				".cdf  will/may be created.");
                 } else {
                   if (abcX == 0 && hlp == 0) {
                           info.setText("");
                           info.append("Program is running...\n");
                   }
-                  Dimension dialogSize = dialog.getSize();
-                  ((JComponent)(dialog.getContentPane())).paintImmediately(
+                }
+                Dimension dialogSize = dialog.getSize();
+                ((JComponent)(dialog.getContentPane())).paintImmediately(
                                                 0, 0, dialogSize.width, dialogSize.height);
 
-                  BufferedReader inStream = new BufferedReader(new
+                BufferedReader inStream = new BufferedReader(new
                                   InputStreamReader(process.getInputStream()), 8192);
-		  boolean first = true;
-		  String line = null;
-                  if (hlp == 1 || abcX == 1 || ricX == 1 || rwcX == 1 || recX == 1 ||
-                      lpcX == 1 || dscX == 1 || dpcX == 1) {
-                    while ((line = inStream.readLine()) != null) {
-		      if (first) {
+		boolean first = true;
+		String line = null;
+                if (hlp == 1 || abcX == 1 || ricX == 1 || rwcX == 1 || recX == 1 ||
+                    lpcX == 1 || dscX == 1 || dpcX == 1) {
+                  while ((line = inStream.readLine()) != null) {
+		    if (first) {
 			info.setText("");
 			first = false;
-		      }
-                      info.append(line+"\n");
 		    }
-                  }
-		  process.waitFor(); 
-		  info.setCaretPosition(0);
-                  if (process.exitValue() == 1) Toolkit.getDefaultToolkit().beep();
-		  else if (hlp == 0 && !abc.isSelected()) {
-			  String myString;
-			  info.append("Done!\n\n");
-			  myString = filespec.trim() + ".cdf";
-			  info.append("CDF:"+myString+"   is created.");
+                    info.append(line+"\n");
+		  }
+                }
+		process.waitFor(); 
+		info.setCaretPosition(0);
+                if (process.exitValue() == 1) {
+		  Toolkit.getDefaultToolkit().beep();
+		  info.append("ERROR: error is detected... job failed\n");
+		} else {
+		  if (iba == 1) {
+			  if (info.getText().toLowerCase().indexOf("error") == -1)
+                            info.append("Done!\n\n");
+			  else
+			    info.append("ERROR: converting file is not created or is invalide.\n");
 		  }
 		}
         } catch (Exception e) {
