@@ -94,6 +94,8 @@ public class CDFDump extends JFrame
 /** The command string. */
     String command = "cdfdump ";
     String commandX;
+    String[] cmds = new String[3];
+
 /** Environment variable for the current directory. */
     String currentdir = System.getProperty("user.dir");
 /** The file separator. */
@@ -297,7 +299,7 @@ public class CDFDump extends JFrame
         makeJButton(panel2n, Box.createRigidArea(hpad40), 1, 1, 1, 1, 0.0, 0.0);
 	makeJButton(panel2n, abc, 2, 1, 1, 1, 0.0, 0.0);
 	makeJButton(panel2n, Box.createRigidArea(hpad40), 3, 1, 1, 1, 0.0, 0.0);
-        makeJButton(panel2n, bac, 4, 1, 1, 1, 0.0, 0.0);
+//        makeJButton(panel2n, bac, 4, 1, 1, 1, 0.0, 0.0);
         makeJButton(panel2n, tpanel1, 0, 2, 1, 1, 0.0, 0.0);
         makeJButton(panel2n, Box.createRigidArea(vpad5), 0, 3, 1, 1, 0.0, 0.0);
         makeJButton(panel2s, Box.createRigidArea(vpad5), 0, 0, 1, 1, 0.0, 0.0);
@@ -403,9 +405,19 @@ public class CDFDump extends JFrame
 	} else if (obj == helpb || obj == menuHelpHelp) { // for "Help" 
 		commandX = command + "-java";
 		hlp = 1;
-		// String[] cmds = {"/bin/sh", "-c", commandX};
-		// runit(cmds);
-		runit(commandX);
+		iba = 0;
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+		runit(cmds);
+		// runit(commandX);
 		hlp = 0;
 	} else if (obj == entrb) { // for "Enter" button
                 cdfspec = cdf.getText();
@@ -429,40 +441,40 @@ public class CDFDump extends JFrame
                 }
 		xxx = " ";
 		if (!filespec.equals("") && !filespec.trim().equals("")) {
-                  String fileName;
-                  int ilast = filespec.lastIndexOf(separator);
-                  if (ilast != -1) fileName = filespec.substring(ilast+1);
-                  else fileName = filespec;
-                  if (fileName.toLowerCase().equals("source")) {
-                    if (cdfspec.toLowerCase().endsWith(".cdf")) {
-                      int jlast = cdfspec.toLowerCase().lastIndexOf(".cdf");
-                      if (jlast != -1) 
-		        xxx = "-output " + cdfspec.substring(0,jlast-1) + ".txt ";
-                      else
-                        xxx = "-output " + cdfspec + ".txt ";
-                    } else {
-                      xxx = "-output " + cdfspec + ".txt ";
-                    }
-                  } else {
-                    if (filespec.toLowerCase().endsWith(".txt")) 
-                      xxx = "-output " + filespec + " ";
-                    else
-                      xxx = "-output " + filespec + ".txt ";
-                  }
-                }
+                  filespec = filespec.trim();
+                  String fileDelimiter;
+                  if (filespec.startsWith("'")) fileDelimiter = " ";
+                  else if (filespec.startsWith("\"")) fileDelimiter = " ";
+                  else fileDelimiter = "\"";
+                  xxx = "-output " + fileDelimiter + filespec +
+                        fileDelimiter + " ";
+                  iba = 1;
+		}
                 if (strvars.equals("") || strvars.trim().equals("")) 
                   yyy = " ";
                 else
                   yyy = "-vars " + strvars.trim() + " ";
+
 		if (cdfspec.startsWith("'")) cdfDelimiter = " ";
 		else if (cdfspec.startsWith("\"")) cdfDelimiter = " ";
-		else cdfDelimiter = "'";
-		commandX = command + struf + "-dump " + strdp + xxx + yyy +
-                           " " + cdfspec;
+		else cdfDelimiter = "\"";
 
-		// String[] cmds = {"/bin/sh", "-c", commandX};
-		// runit(cmds);
-		runit(commandX);
+		commandX = command + struf + "-dump " + strdp + " " + xxx + yyy +
+                           " " + cdfDelimiter + cdfspec + cdfDelimiter;
+
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    commandX = commandX.replace('-', '/');
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+		runit(cmds);
+		// runit(commandX);
 	} else if (obj == cdf) {
 		cdfspec = cdf.getText();
 	} else if (obj == outf) {
@@ -530,10 +542,20 @@ public class CDFDump extends JFrame
 	if (obj == abc) { // "About" checkbox
 	   if (abc.isSelected()) {
 		abcX = 1;
+		iba = 0;
                 commandX = command + " -about";
-		// String[] cmds = {"/bin/sh", "-c", commandX};
-		// runit(cmds);
-		runit(commandX);
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+		runit(cmds);
+		// runit(commandX);
                 abc.setSelected(false);
 		abcX = 0;
 	   }
@@ -619,16 +641,14 @@ public class CDFDump extends JFrame
     the results in the text area.
  */
 
-    // private void runit(String[] command) {
-    private void runit(String command) {
+    private void runit(String[] command) {
+    // private void runit(String command) {
 	try {
-           if (System.getProperty("os.name").toLowerCase().indexOf("vms") != -1)
-              command = command.replace('-', '/');
-
-	      // if (System.getProperty("os.name").equalsIgnoreCase("VMS"))
-	      //    command[2] = command[2].replace('-', '/');
-
-              process = runtime.exec(command);
+	      if (command[1] != null)
+                process = runtime.exec(command);
+              else
+                process = runtime.exec(command[0]);
+/*
               if (hlp == 0 && abcX == 0) {
                 if (!filespec.equals("") && !filespec.trim().equals("")) {                 
                   info.setText("Program is submitted...\n\n");
@@ -640,6 +660,7 @@ public class CDFDump extends JFrame
                   info.append("Program is running...\n");
                 }
               }
+*/
               Dimension dialogSize = dialog.getSize();
               ((JComponent)(dialog.getContentPane())).paintImmediately(
                                             0, 0, dialogSize.width, dialogSize.height);
@@ -661,14 +682,13 @@ public class CDFDump extends JFrame
               scroller.revalidate();
               scroller.repaint();
 
-              if (hlp == 0 && abcX == 0) {
-                if (!filespec.equals("") && !filespec.trim().equals("")) {
-                  String myString;
+              if (iba == 1) {
+                String outofpgm = info.getText().toLowerCase().trim();
+                if (outofpgm.indexOf("error") != -1 || 
+                    outofpgm.indexOf("fail") != -1)
+                  info.append("ERROR: Dump file is not created\n"); 
+                else
                   info.append("Done!\n\n");
-                  myString = filespec.trim() + ".txt";
-                  info.append("A dump file: "+xxx.substring(8).trim()+
-                              "   is created.");
-                }
 	      }
         } catch (Exception e) {
               info.setText("error executing: "+e);
