@@ -88,8 +88,10 @@ public class CDFIRsDump extends JFrame
     SimpleFileFilter filter = new SimpleFileFilter(cdfs,
                                                 " CDF files (*.cdf, *.CDF)");
 /** The command string. */
-    String command = "cdfdump ";
+    String command = "cdfirsdump ";
     String commandX;
+    String[] cmds = new String[3];
+
 /** Environment variable for the current directory. */
     String currentdir = System.getProperty("user.dir");
 /** The file separator. */
@@ -180,7 +182,7 @@ public class CDFIRsDump extends JFrame
 
     CDFIRsDump(JFrame parentFrame, String cdfbase, boolean modal) {
         if (cdfbase != null) command = cdfbase + separator + "bin" + 
-				       separator + "cdfdump ";
+				       separator + "cdfirsdump ";
         dialog = new JDialog(this, modal);
 	this.parentFrame = parentFrame;
         this.modal = modal;
@@ -201,7 +203,7 @@ public class CDFIRsDump extends JFrame
 	   }
         };
         dialog.addWindowListener(l);
-        dialog.setTitle("Enter   Parameters/qualifiers  for  CDFcompare");
+        dialog.setTitle("Enter   Parameters/qualifiers  for  CDFIRsDump");
         dialog.setSize(INITIAL_WIDTH, INITIAL_HEIGHT);
         dialog.setLocation(screenSize.width/2 - INITIAL_WIDTH/2,
                           screenSize.height/2 - INITIAL_HEIGHT/2);
@@ -286,16 +288,17 @@ public class CDFIRsDump extends JFrame
         dumpPanel.add(dump1);
         dumpPanel.add(dump2);
 
-	makeJButton(panel2, pgc, 0, 0, 1, 1, 0.0, 0.0);
-        makeJButton(panel2, csc, 1, 0, 1, 1, 0.0, 0.0);
-        makeJButton(panel2, ssc, 2, 0, 1, 1, 0.0, 0.0);
+//	makeJButton(panel2, pgc, 0, 0, 1, 1, 0.0, 0.0);
+        makeJButton(panel2, csc, 0, 0, 1, 1, 0.0, 0.0);
+        makeJButton(panel2, ssc, 1, 0, 1, 1, 0.0, 0.0);
         makeJButton(panel2, sic, 0, 1, 1, 1, 0.0, 0.0);
-        makeJButton(panel2, bac, 1, 1, 1, 1, 0.0, 0.0);
+	makeJButton(panel2, abc, 1, 1, 1, 1, 0.0, 0.0);
+//        makeJButton(panel2, bac, 1, 1, 1, 1, 0.0, 0.0);
         tpanel1.add(DUMP,BorderLayout.WEST);
         tpanel1.add(dumpPanel, BorderLayout.CENTER);
         tpanel1.add(Box.createRigidArea(hpad20), BorderLayout.EAST);
-        makeJButton(panel2, tpanel1, 2, 1, 1, 1, 0.0, 0.0);
-	makeJButton(panel2, abc, 0, 2, 1, 1, 0.0, 0.0);
+        makeJButton(panel2, tpanel1, 0, 2, 1, 1, 0.0, 0.0);
+
 	makeJButton(panel2, Box.createRigidArea(vpad20), 0, 3, 1, 1, 0.0, 0.0);
 
 	pgc.addItemListener(this);
@@ -402,8 +405,18 @@ public class CDFIRsDump extends JFrame
 	} else if (obj == helpb || obj == menuHelpHelp) { // for "Help" 
 		commandX = command + "-java";
 		hlp = 1;
+		iba = 0;
 		info.setText("");
-                String[] cmds = {"/bin/sh", "-c", commandX};
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
                 runit(cmds);
 		hlp = 0;
 	} else if (obj == entrb) { // for "Enter" button
@@ -415,31 +428,44 @@ public class CDFIRsDump extends JFrame
                   Toolkit.getDefaultToolkit().beep();
                   return;
 		}
-
+/*
                 if (iba == 1) {
-                  if (filespec.equals("") || filespec.trim().equals("")) {
+                if (!filespec.equals("") && !filespec.trim().equals("")) {
                     info.setText("");
                     info.append("Please enter the output file for a batch run..");
                     Toolkit.getDefaultToolkit().beep();
                     return;
                   }
                 }
-
+*/
 		xxx = " ";
-		if (!filespec.equals("") && !filespec.trim().equals("")) 
-			xxx = "-output ";
-                if (filespec.trim().equals("")) fileDelimiter = " ";
-		else if (filespec.startsWith("'")) fileDelimiter = " ";
-                else if (filespec.startsWith("\"")) fileDelimiter = " ";
-                else fileDelimiter = "'";
+		if (!filespec.equals("") && !filespec.trim().equals("")) {
+                  iba = 1;
+                  filespec = filespec.trim();
+		  if (filespec.startsWith("'")) fileDelimiter = " ";
+                  else if (filespec.startsWith("\"")) fileDelimiter = " ";
+                  else fileDelimiter = "\"";
+                  xxx = "-output " + fileDelimiter + filespec + fileDelimiter;
+                } else
+                  iba = 0;
+  
                 if (cdfspec.startsWith("'")) cdfDelimiter = " ";
                 else if (cdfspec.startsWith("\"")) cdfDelimiter = " ";
-                else cdfDelimiter = "'";
+                else cdfDelimiter = "\"";
 
 		commandX = command + strpo + strcs + strss + strsi + strds + 
-			   xxx + fileDelimiter + filespec + fileDelimiter + " " +
-			   cdfDelimiter + cdfspec + cdfDelimiter;
-                String[] cmds = {"/bin/sh", "-c", commandX};
+			   xxx + " " + cdfDelimiter + cdfspec + cdfDelimiter;
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    commandX = commandX.replace('-', '/');
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
                 runit(cmds);
 	} else if (obj == cdf) {
 		cdfspec = cdf.getText();
@@ -506,8 +532,18 @@ public class CDFIRsDump extends JFrame
 	} else if (obj == abc) { // "About" checkbox
 	   if (abc.isSelected()) {
 		abcX = 1;
+		iba = 0;
                 commandX = command + " -about";
-                String[] cmds = {"/bin/sh", "-c", commandX};
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
                 runit(cmds);
                 abc.setSelected(false);
 		abcX = 0;
@@ -609,41 +645,38 @@ public class CDFIRsDump extends JFrame
 
     private void runit(String[] command) {
 	try {
-	      if (System.getProperty("os.name").equalsIgnoreCase("VMS"))
-		command[2] = command[2].replace('-', '/');
-              process = runtime.exec(command);
-              if (iba == 1 && hlp == 0 && abcX == 0) {
+              if (command[1] != null)
+                process = runtime.exec(command);
+              else
+                process = runtime.exec(command[0]);
+              if (iba == 1) {
                  info.setText("Program is submitted...\n\n");
-		 info.append("A statistics file: " + filespec.trim() + 
-				".dmp  will/may be created.");
-              } else {
+              } else { 
                 if (abcX == 0 && hlp == 0) {
                    info.setText("");
                    info.append("Program is running...\n");
                 }
-                Dimension dialogSize = dialog.getSize();
-                ((JComponent)(dialog.getContentPane())).paintImmediately(
+              }
+              Dimension dialogSize = dialog.getSize();
+              ((JComponent)(dialog.getContentPane())).paintImmediately(
                                                 0, 0, dialogSize.width, dialogSize.height);
-                String line = null;
-                BufferedReader inStream = new BufferedReader(new
+              String line = null;
+              BufferedReader inStream = new BufferedReader(new
                                       InputStreamReader(process.getInputStream()), 8192);
-		info.setText("");
-//                if (hlp == 1 || abcX == 1) {
-                    while ((line = inStream.readLine()) != null)
-                      info.append(line+"\n");
-//                }
-                process.waitFor();
-		info.setCaretPosition(0);
-                if (process.exitValue() == 1) {
+	      info.setText("");
+              while ((line = inStream.readLine()) != null)
+                info.append(line+"\n");
+              process.waitFor();
+	      info.setCaretPosition(0);
+              if (process.exitValue() == 1) {
 		  if (!filespec.equals("")) info.append("Error detected...\n");
 		  Toolkit.getDefaultToolkit().beep();
-	        }
-                else if (hlp == 0 && abcX == 0 && !filespec.equals("")) {
-                     String myString;
-                     info.append("Done!\n\n");
-                     myString = filespec.trim() + ".dmp";
-                     info.append("A statistics file: "+myString+"   is created.\n");
-                }
+	      }
+              if (iba == 1) {
+                 if (info.getText().toLowerCase().indexOf("error") == -1) {
+                   info.append("Done!\n\n");
+		 } else
+		   info.append("ERROR: dump file is not created.\n");
 	      }
         } catch (Exception e) {
               info.setText("error executing: "+e);
@@ -683,11 +716,6 @@ public class CDFIRsDump extends JFrame
                   if (ind != -1) myfile = myfile.substring(0, ind);
                   ind = myfile.lastIndexOf(".CDF");
                   if (ind != -1) myfile = myfile.substring(0, ind);
-              } else { // for .skt file
-                  ind = myfile.lastIndexOf(".skt");
-                  if (ind != -1) myfile = myfile.substring(0, ind);
-                  ind = myfile.lastIndexOf(".SKT");
-                  if (ind != -1) myfile = myfile.substring(0, ind);
               }
 	      fileChooser.setCurrentDirectory(selectedFile);
               textField.setText(myfile);
