@@ -121,6 +121,8 @@ public class CDFMerge extends JFrame
 /** The command string. */
     String command = "cdfmerge ";
     String commandX;
+    String[] cmds = new String[3];
+
 /** Environment variable for the current directory. */
     String currentdir = System.getProperty("user.dir");
 /** The file separator. */
@@ -504,7 +506,18 @@ public class CDFMerge extends JFrame
 	} else if (obj == helpb || obj == menuHelpHelp) { // for "Help" 
 		commandX = command + " -java";
 		hlp = 1;
-                runit(commandX);
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+
+                runit(cmds);
 		hlp = 0;
 	} else if (obj == entrb) { // for "Enter" button
                 cdf1spec = cdf1.getText();
@@ -605,8 +618,18 @@ public class CDFMerge extends JFrame
                     commandX = command + np + strdo + strcw + stral + 
                                mastspec + Prefix + strut;
 
-                // System.out.println("commandX = "+commandX);
-                runit(commandX);
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+
+                runit(cmds);
 
 	// } else if (obj == cdf1) {
         //		cdf1spec = cdf1.getText();
@@ -687,7 +710,18 @@ public class CDFMerge extends JFrame
 	   if (abc.isSelected()) {
 		abcX = 1;
 		commandX = command + " -about";
-                runit(commandX);
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+
+                runit(cmds);
 		abc.setSelected(false);
 		abcX = 0;
 	   }
@@ -776,12 +810,13 @@ public class CDFMerge extends JFrame
     the results in the text area.
  */
 
-    private void runit(String command) {
+    private void runit(String[] command) {
 	try {
-           if (System.getProperty("os.name").toLowerCase().indexOf("vms") != -1)
-               command = command.replace('-', '/');
-
-           process = runtime.exec(command);
+           
+           if (command[1] != null) 
+             process = runtime.exec(command);
+           else
+             process = runtime.exec(command[0]);
 
            if (abcX == 0 && hlp == 0) {
                info.setText("");
@@ -809,7 +844,10 @@ public class CDFMerge extends JFrame
            if (process.exitValue() == 1) 
                Toolkit.getDefaultToolkit().beep();
 	   else if (hlp == 0 && !abc.isSelected()) {
-	       info.append("Done!\n\n");
+               if (info.getText().toLowerCase().indexOf("error") == -1)
+	         info.append("Done!\n\n");
+               else
+                 info.append("Error: merging is not done...\n\n");
 	   }
 
         } catch (Exception e) {
