@@ -152,6 +152,7 @@ public class CDFStats extends JFrame
     Process process = null;
     int hlp = 0;
     int iba = 0;
+    String[] cmds = new String[3];
 
 /** The text field is currently getting the focus. */
     JTextField focused = null;
@@ -349,11 +350,11 @@ public class CDFStats extends JFrame
         makeJButton(panel2n, zzc, 4, 3, 1, 1, 1.0, 1.0);
 	makeJButton(panel2n, abc, 0, 4, 1, 1, 1.0, 1.0);
 	makeJButton(panel2n, Box.createRigidArea(hpad40), 1, 4, 1, 1, 1.0, 1.0);
-	makeJButton(panel2n, bac, 2, 4, 1, 1, 1.0, 1.0);	
+//	makeJButton(panel2n, bac, 2, 4, 1, 1, 1.0, 1.0);	
         tpanel1.add(ZMODE,BorderLayout.WEST);
         tpanel1.add(zmodePanel, BorderLayout.CENTER);
         tpanel1.add(Box.createRigidArea(hpad20), BorderLayout.EAST);
-        makeJButton(panel2n, tpanel1, 4, 4, 1, 1, 1.0, 1.0);
+        makeJButton(panel2n, tpanel1, 2, 4, 1, 1, 1.0, 1.0);
 //        makeJButton(panel2n, Box.createRigidArea(hpad40), 1, 4, 1, 1, 1.0, 1.0);
 //	makeJButton(panel2n, abc, 0, 4, 1, 1, 1.0, 1.0);
 //        makeJButton(panel2n, Box.createRigidArea(hpad40), 3, 4, 1, 1, 1.0, 1.0);
@@ -483,11 +484,20 @@ public class CDFStats extends JFrame
 		doFileChooser("Select/enter the output file", outf, 1, null);
              }
 	} else if (obj == helpb || obj == menuHelpHelp) { // for "Help" 
-		commandX = command + "-java";
-		hlp = 1;
-		// String[] cmds = {"/bin/sh", "-c", commandX};
-		// runit(cmds);
-		runit(commandX);
+                 commandX = command + "-java";
+                 hlp = 1;
+                 String OS = System.getProperty("os.name").toLowerCase();
+                 if (OS.indexOf("windows") != -1) {
+                     cmds[0] = commandX;
+                 } else if (OS.indexOf("vms") != -1) {
+                     cmds[0] = commandX;
+                 } else {
+		     cmds[0] = "/bin/sh";
+		     cmds[1] = "-c";
+		     cmds[2] = commandX;
+                }
+		runit(cmds);
+//		runit(commandX);
 		hlp = 0;
 	} else if (obj == entrb) { // for "Enter" button
                 cdfspec = cdf.getText();
@@ -497,7 +507,9 @@ public class CDFStats extends JFrame
                   info.append("Please enter a CDF file...");
                   Toolkit.getDefaultToolkit().beep();
                   return;
-                }
+                } else
+                  cdfspec = cdfspec.trim();
+/*
                 if (iba == 1) {
                   if (filespec.equals("") || filespec.trim().equals("")) {
                     info.setText("");
@@ -506,7 +518,7 @@ public class CDFStats extends JFrame
                     return;
                   }
                 }
-
+*/
 		temp = strri + strrw + strre;
 		if (temp.length() == 0) report = " ";
 		else if (temp.length() == 3) report = "-report \"i,w,e\" ";
@@ -524,8 +536,17 @@ public class CDFStats extends JFrame
 		else Zmode = "-zmode " + strzm + " ";
 
 		xxx = " ";
-		if (!filespec.equals("") && !filespec.trim().equals("")) 
-			xxx = "-output " + filespec + " ";
+		if (!filespec.equals("") && !filespec.trim().equals("")) {
+                  filespec = filespec.trim();
+		  String fileDelimiter;
+                  if (filespec.startsWith("'")) fileDelimiter = " ";
+                  else if (filespec.startsWith("\"")) fileDelimiter = " ";
+                  else fileDelimiter = "\"";
+                  xxx = "-output " + fileDelimiter + filespec +
+                        fileDelimiter + " ";
+                  iba = 1;
+                } else
+                  iba = 0;
 
                 strcs = cachesizes.getText();
                 if (strcs.equals("") || strcs.trim().equals("")) Caches = " ";
@@ -535,19 +556,30 @@ public class CDFStats extends JFrame
 
 		if (cdfspec.startsWith("'")) cdfDelimiter = " ";
 		else if (cdfspec.startsWith("\"")) cdfDelimiter = " ";
-		else cdfDelimiter = "'";
-		/***
+		else cdfDelimiter = "\"";
+		
                 commandX = command + strpo + struf + strrc + strui +
                            struv   + strus + strum + strzz + strds + 
 			   report + Zmode + Caches + xxx + cdfDelimiter +
 			   cdfspec + cdfDelimiter;
-                *****/
-		commandX = command + strpo + struf + strrc + strui +
-                           struv   + strus + strum + strzz + strds + 
-			   report + Zmode + Caches + xxx + " " + cdfspec;
-		// String[] cmds = {"/bin/sh", "-c", commandX};
-		// runit(cmds);
-		runit(commandX);
+               
+//		commandX = command + strpo + struf + strrc + strui +
+//                           struv   + strus + strum + strzz + strds + 
+//			   report + Zmode + Caches + xxx + " " + cdfspec;
+
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    commandX = commandX.replace('-', '/');
+                    cmds[0] = commandX;
+                } else {
+		    cmds[0] = "/bin/sh";
+		    cmds[1] = "-c";
+		    cmds[2] = commandX;
+		}
+		runit(cmds);
+//		runit(commandX);
 	} else if (obj == cdf) {
 		cdfspec = cdf.getText();
 	} else if (obj == outf) {
@@ -626,9 +658,18 @@ public class CDFStats extends JFrame
 	   if (abc.isSelected()) {
 		abcX = 1;
                 commandX = command + " -about";
-		// String[] cmds = {"/bin/sh", "-c", commandX};
-		// runit(cmds);
-		runit(commandX);
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+		    cmds[0] = "/bin/sh";
+		    cmds[1] = "-c";
+		    cmds[2] = commandX;
+		}
+		runit(cmds);
+//		runit(commandX);
                 abc.setSelected(false);
 		abcX = 0;
 	   }
@@ -776,58 +817,62 @@ public class CDFStats extends JFrame
     the results in the text area.
  */
 
-    // private void runit(String[] command) {
-    private void runit(String command) {
+     private void runit(String[] command) {
+//    private void runit(String command) {
 	try {
-
-	      // if (System.getProperty("os.name").equalsIgnoreCase("VMS"))
-              //	command[2] = command[2].replace('-', '/');
-
-              process = runtime.exec(command);
+              if (command[1] != null) 
+                process = runtime.exec(command);
+              else
+                process = runtime.exec(command[0]);
+/*
               if (iba == 1 && hlp == 0 && abcX == 0) {
                  info.setText("Program is submitted...\n\n");
-		 info.append("A statistics file: " + filespec.trim() + 
-				".sts  will/may be created.");
+                 int idx = filespec.indexOf('.');
+		 info.append("A statistics file: " + filespec + 
+				(idx != -1 ? "" : ".sts") + " will/may be created.");
               } else {
                 if (abcX == 0 && hlp == 0) {
                    info.setText("");
                    info.append("Program is running...\n");
                 }
-
-                Dimension dialogSize = dialog.getSize();
-                ((JComponent)(dialog.getContentPane())).paintImmediately(
-                                                0, 0, dialogSize.width, dialogSize.height);
-                BufferedReader inStream = null;
-                String line = null;
-                inStream = new BufferedReader(new
+              }
+*/
+              Dimension dialogSize = dialog.getSize();
+              ((JComponent)(dialog.getContentPane())).paintImmediately(
+                                              0, 0, dialogSize.width, dialogSize.height);
+              BufferedReader inStream = null;
+              String line = null;
+              inStream = new BufferedReader(new
                                       InputStreamReader(process.getInputStream()), 8192);
-	 	boolean first = true;	
-                if (hlp == 1 || abcX == 1 || ricX == 1 || rwcX == 1 || recX == 1 ||
-                    dscX == 1) {
-                  while ((line = inStream.readLine()) != null) {
+	      boolean first = true;	
+//              if (hlp == 1 || abcX == 1 || ricX == 1 || rwcX == 1 || recX == 1 ||
+//                    dscX == 1) {
+                while ((line = inStream.readLine()) != null) {
 		    if (first) {
 			info.setText("");
 			first =false;
 		    }
                     info.append(line+"\n");
-		  }
-                }
-                process.waitFor();
-		info.setCaretPosition(0);
-                if (process.exitValue() == 1) {
-		  if (!filespec.equals("")) info.append("Error detected...\n");
+		}
+//              }
+              process.waitFor();
+	      info.setCaretPosition(0);
+              if (process.exitValue() == 1) {
 		  Toolkit.getDefaultToolkit().beep();
-	        } 
+		  info.append("ERROR: error is detected... job failed\n");
+	      } else { 
                 scroller.getViewport().setView(info);
                 scroller.revalidate();
                 scroller.repaint();
-                if (hlp == 0 && abcX == 0 && !filespec.equals("")) {
-                     String myString;
-                     info.append("Done!\n\n");
-                     myString = filespec.trim() + ".sts";
-                     info.append("A statistics file: "+myString+"   is created.");
-                }
-	     }
+		if (iba == 1) {
+                     if (info.getText().toLowerCase().indexOf("error") == -1) {
+                       info.append("Done!\n\n");
+//                       info.append("A statistics file: "+myString+"   is created.");
+		     } else {
+		       info.append("ERROR: check the statistics file for error information.");
+		     }
+		}
+              }
         } catch (Exception e) {
               info.setText("error executing: "+e);
 	      Toolkit.getDefaultToolkit().beep();
