@@ -139,6 +139,7 @@ public class SkeletonTable extends JFrame
 /** The command string. */
     String command = "skeletontable ";
     String commandX;
+    String[] cmds = new String[3];
 
 /** Environment variable for the current directory. */
     String currentdir = System.getProperty("user.dir");
@@ -417,7 +418,7 @@ public class SkeletonTable extends JFrame
         makeJButton(panel2n, Box.createRigidArea(hpad40), 1, 2, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, rec, 2, 2, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, Box.createRigidArea(hpad40), 3, 2, 1, 1, 1.0, 1.0);
-        makeJButton(panel2n, bac, 4, 2, 1, 1, 1.0, 1.0);
+//        makeJButton(panel2n, bac, 4, 2, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, lpc, 0, 3, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, Box.createRigidArea(hpad40), 1, 3, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, abc, 2, 3, 1, 1, 1.0, 1.0);
@@ -558,11 +559,22 @@ public class SkeletonTable extends JFrame
 	} else if (obj == helpb || obj == menuHelpHelp) { // for "Help" 
 		commandX = command + "-java";
 		hlp = 1;
-                // String[] cmds = {"/bin/sh", "-c", commandX};
-                // runit(cmds);
-                runit(commandX);
+		iba = 0;
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+                runit(cmds);
+                // runit(commandX);
 		hlp = 0;
 	} else if (obj == entrb) { // for "Enter" button
+		iba = 1;
                 cdfspec = cdf.getText();
                 skltspec = sklt.getText();
 		if (cdfspec.equals("") || cdfspec.trim().equals("")) {
@@ -602,16 +614,17 @@ public class SkeletonTable extends JFrame
                         if (strzm.equals("")) Zmode = " ";
                         else Zmode = "-zmode " + strzm + " ";
 
-			if (skltspec.trim().equals("")) SKLTfile = " ";
+			if (skltspec.equals("") || skltspec.trim().equals("")) 
+			  SKLTfile = " ";
 			else {
-                  	  if (skltspec.startsWith("'")) sktDelimiter = " ";
+			  if (skltspec.startsWith("'")) sktDelimiter = " ";
                   	  else if (skltspec.startsWith("\"")) sktDelimiter = " ";
-                  	  else sktDelimiter = "'";
-                  	  /********
+                  	  else sktDelimiter = "\"";
                           SKLTfile = "-skeleton " + sktDelimiter + skltspec + 
 				     sktDelimiter + " ";
-                          *********/
+                          /*********
                   	  SKLTfile = "-skeleton " + " " + skltspec + " ";
+                          *********/
 			}
 
 	                caches = cachesizes.getText();
@@ -622,20 +635,30 @@ public class SkeletonTable extends JFrame
 
                         if (cdfspec.startsWith("'")) cdfDelimiter = " ";
                         else if (cdfspec.startsWith("\"")) cdfDelimiter = " ";
-                        else cdfDelimiter = "'";
+                        else cdfDelimiter = "\"";
 
-			/*************
                         commandX = command  + strzz + struf + stros + strlp +
 				   strds + strpo + report + Zmode + Values +
 				   Caches + SKLTfile + cdfDelimiter + cdfspec +
 				   cdfDelimiter;
-                        **************/
+                        /**************
 			commandX = command  + strzz + struf + stros + strlp +
 				   strds + strpo + report + Zmode + Values +
 				   Caches + SKLTfile + " " + cdfspec + " ";
-                	// String[] cmds = {"/bin/sh", "-c", commandX};
-                	// runit(cmds);
-                	runit(commandX);
+                        *************/
+                        String OS = System.getProperty("os.name").toLowerCase();
+                        if (OS.indexOf("windows") != -1) {
+                            cmds[0] = commandX;
+                        } else if (OS.indexOf("vms") != -1) {
+                            commandX = commandX.replace('-', '/');
+                            cmds[0] = commandX;
+                        } else {
+                            cmds[0] = "/bin/sh";
+                            cmds[1] = "-c";
+                            cmds[2] = commandX;
+                        }
+                	runit(cmds);
+                	// runit(commandX);
 		} 
 	} else if (obj == cdf) { // "CDF" text field
 		cdfspec = cdf.getText();
@@ -735,10 +758,20 @@ public class SkeletonTable extends JFrame
 	} else if (obj == abc) { // "About" checkbox
                 if (abc.isSelected()) {
 		  abcX = 1;
+		  iba = 0;
 		  commandX = command + " -about";
-                  // String[] cmds = {"/bin/sh", "-c", commandX};
-                  // runit(cmds);
-                  runit(commandX);
+                  String OS = System.getProperty("os.name").toLowerCase();
+                  if (OS.indexOf("windows") != -1) {
+                      cmds[0] = commandX;
+                  } else if (OS.indexOf("vms") != -1) {
+                      cmds[0] = commandX;
+                  } else {
+                      cmds[0] = "/bin/sh";
+                      cmds[1] = "-c";
+                      cmds[2] = commandX;
+                  }
+                  runit(cmds);
+                  // runit(commandX);
                   abc.setSelected(false);
 		  abcX = 0;
 		}
@@ -885,14 +918,14 @@ public class SkeletonTable extends JFrame
     the results in the text area.
  */
 
-    // private void runit(String[] command) {
-    private void runit(String command) {
+    private void runit(String[] command) {
+    // private void runit(String command) {
 	try {
-	   if (System.getProperty("os.name").toLowerCase().indexOf("vms") != -1)
-	      command = command.replace('-', '/');
-	      // command[2] = command[2].replace('-', '/');
-
-                process = runtime.exec(command);
+                if (command[1] != null)
+                  process = runtime.exec(command);
+                else
+                  process = runtime.exec(command[0]);
+/*
                 if (iba == 1 && hlp == 0 && abcX == 0) {
                         info.setText("Program is submitted...\n\n");
                         String myString;
@@ -908,6 +941,7 @@ public class SkeletonTable extends JFrame
                   if (abcX == 0 && hlp == 0) {
                           info.setText("Program is running...\n");
                   }
+*/
 		  Dimension dialogSize = dialog.getSize();
 		  ((JComponent)(dialog.getContentPane())).paintImmediately(
   						0, 0, dialogSize.width, dialogSize.height);
@@ -927,20 +961,16 @@ public class SkeletonTable extends JFrame
 		  }
                   process.waitFor();
 		  info.setCaretPosition(0);
-		  if (process.exitValue() == 1) Toolkit.getDefaultToolkit().beep();
-                  else if (hlp == 0 && abcX == 0 && oscX == 0) {
-			String myString;
-                        info.append("Done!\n\n");
-			if (sklt.getText().equals("")) {
-			  myString = cdf.getText().trim();
-			  int id;
-			  id = myString.lastIndexOf('/');
-			  if (id > 0) myString = myString.substring(id+1); 
-			  myString = myString + ".skt";
-			} else myString = sklt.getText().trim() + ".skt";
-			info.append("A skeleton table: "+myString+"   is created.\n");
-		  }
-		} 
+		  if (process.exitValue() == 1) 
+		    Toolkit.getDefaultToolkit().beep();
+                  else {
+		    if (iba == 1) {
+			if (info.getText().toLowerCase().indexOf("error") == -1)
+			  info.append("Done!\n\n");
+			else 
+			  info.append("ERROR: skeleton table is invalid.\n");
+		    }
+		  } 
 	} catch (Exception e) {
                 info.setText("error executing: "+e);
                 Toolkit.getDefaultToolkit().beep();
